@@ -15,10 +15,10 @@ Usage::
 import sys
 from typing import Any, Dict, Type
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 
 from .paginator import ListEndpointsPaginator
-from .type_defs import CreateEndpointResultResponseTypeDef, ListEndpointsResultResponseTypeDef
+from .type_defs import CreateEndpointResultTypeDef, ListEndpointsResultTypeDef
 
 if sys.version_info >= (3, 8):
     from typing import Literal
@@ -46,31 +46,36 @@ class Exceptions:
     ValidationException: Type[BotocoreClientError]
 
 
-class S3OutpostsClient:
+class S3OutpostsClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/s3outposts.html#S3Outposts.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/s3outposts.html#S3Outposts.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        S3OutpostsClient exceptions.
+        """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/s3outposts.html#S3Outposts.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/s3outposts.html#S3Outposts.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/client.html#can_paginate)
         """
 
     def create_endpoint(
         self, *, OutpostId: str, SubnetId: str, SecurityGroupId: str
-    ) -> CreateEndpointResultResponseTypeDef:
+    ) -> CreateEndpointResultTypeDef:
         """
         S3 on Outposts access points simplify managing data access at scale for shared
         datasets in Amazon S3 on Outposts.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/s3outposts.html#S3Outposts.Client.create_endpoint)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/s3outposts.html#S3Outposts.Client.create_endpoint)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/client.html#create_endpoint)
         """
 
@@ -79,7 +84,7 @@ class S3OutpostsClient:
         S3 on Outposts access points simplify managing data access at scale for shared
         datasets in Amazon S3 on Outposts.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/s3outposts.html#S3Outposts.Client.delete_endpoint)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/s3outposts.html#S3Outposts.Client.delete_endpoint)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/client.html#delete_endpoint)
         """
 
@@ -93,23 +98,23 @@ class S3OutpostsClient:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/s3outposts.html#S3Outposts.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/s3outposts.html#S3Outposts.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/client.html#generate_presigned_url)
         """
 
     def list_endpoints(
         self, *, NextToken: str = None, MaxResults: int = None
-    ) -> ListEndpointsResultResponseTypeDef:
+    ) -> ListEndpointsResultTypeDef:
         """
         S3 on Outposts access points simplify managing data access at scale for shared
         datasets in Amazon S3 on Outposts.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/s3outposts.html#S3Outposts.Client.list_endpoints)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/s3outposts.html#S3Outposts.Client.list_endpoints)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/client.html#list_endpoints)
         """
 
     def get_paginator(self, operation_name: Literal["list_endpoints"]) -> ListEndpointsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/s3outposts.html#S3Outposts.Paginator.ListEndpoints)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/s3outposts.html#S3Outposts.Paginator.ListEndpoints)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/paginators.html#listendpointspaginator)
         """
