@@ -22,21 +22,21 @@ from typing import Iterator
 
 from botocore.paginate import Paginator as Boto3Paginator
 
-from .type_defs import ListEndpointsResultResponseTypeDef, PaginatorConfigTypeDef
+from .type_defs import ListEndpointsResultTypeDef, PaginatorConfigTypeDef
 
 __all__ = ("ListEndpointsPaginator",)
 
 
 class ListEndpointsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/s3outposts.html#S3Outposts.Paginator.ListEndpoints)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/s3outposts.html#S3Outposts.Paginator.ListEndpoints)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/paginators.html#listendpointspaginator)
     """
 
     def paginate(
         self, *, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListEndpointsResultResponseTypeDef]:
+    ) -> Iterator[ListEndpointsResultTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/s3outposts.html#S3Outposts.Paginator.ListEndpoints.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/s3outposts.html#S3Outposts.Paginator.ListEndpoints.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/paginators.html#listendpointspaginator)
         """
