@@ -6,9 +6,9 @@ Type annotations for s3outposts service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_s3outposts.type_defs import CreateEndpointRequestTypeDef
+    from mypy_boto3_s3outposts.type_defs import CreateEndpointRequestRequestTypeDef
 
-    data: CreateEndpointRequestTypeDef = {...}
+    data: CreateEndpointRequestRequestTypeDef = {...}
     ```
 """
 import sys
@@ -24,19 +24,19 @@ else:
 
 
 __all__ = (
-    "CreateEndpointRequestTypeDef",
-    "CreateEndpointResultResponseTypeDef",
-    "DeleteEndpointRequestTypeDef",
+    "CreateEndpointRequestRequestTypeDef",
+    "CreateEndpointResultTypeDef",
+    "DeleteEndpointRequestRequestTypeDef",
     "EndpointTypeDef",
-    "ListEndpointsRequestTypeDef",
-    "ListEndpointsResultResponseTypeDef",
+    "ListEndpointsRequestRequestTypeDef",
+    "ListEndpointsResultTypeDef",
     "NetworkInterfaceTypeDef",
     "PaginatorConfigTypeDef",
     "ResponseMetadataTypeDef",
 )
 
-CreateEndpointRequestTypeDef = TypedDict(
-    "CreateEndpointRequestTypeDef",
+CreateEndpointRequestRequestTypeDef = TypedDict(
+    "CreateEndpointRequestRequestTypeDef",
     {
         "OutpostId": str,
         "SubnetId": str,
@@ -44,16 +44,16 @@ CreateEndpointRequestTypeDef = TypedDict(
     },
 )
 
-CreateEndpointResultResponseTypeDef = TypedDict(
-    "CreateEndpointResultResponseTypeDef",
+CreateEndpointResultTypeDef = TypedDict(
+    "CreateEndpointResultTypeDef",
     {
         "EndpointArn": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-DeleteEndpointRequestTypeDef = TypedDict(
-    "DeleteEndpointRequestTypeDef",
+DeleteEndpointRequestRequestTypeDef = TypedDict(
+    "DeleteEndpointRequestRequestTypeDef",
     {
         "EndpointId": str,
         "OutpostId": str,
@@ -73,8 +73,8 @@ EndpointTypeDef = TypedDict(
     total=False,
 )
 
-ListEndpointsRequestTypeDef = TypedDict(
-    "ListEndpointsRequestTypeDef",
+ListEndpointsRequestRequestTypeDef = TypedDict(
+    "ListEndpointsRequestRequestTypeDef",
     {
         "NextToken": str,
         "MaxResults": int,
@@ -82,8 +82,8 @@ ListEndpointsRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListEndpointsResultResponseTypeDef = TypedDict(
-    "ListEndpointsResultResponseTypeDef",
+ListEndpointsResultTypeDef = TypedDict(
+    "ListEndpointsResultTypeDef",
     {
         "Endpoints": List["EndpointTypeDef"],
         "NextToken": str,
